@@ -62,9 +62,10 @@ def run_simulation(n_of_families = 250,
         How many days the social distancing last. Use 0 to make the restriction last till the end of the simulation
 
     social_distance_strictness: int
-        How strict from 0 to 4 the social distancing measures are. 
-        Represent the portion of contact that are dropped in the network (0, 25%, 50%, 75%, 100%)
+        How strict from 0 to 100 the social distancing measures are. 
+        Represent the percentage of contact that are dropped in the network
         Note that family contacts are not included in this reduction
+        Use 0 if you don't want to use restrictions
 
     restriction_decreasing: bool
         If the social distancing will decrease the strictness during the restriction_duration period
@@ -150,7 +151,7 @@ def run_simulation(n_of_families = 250,
     if initial_day_restriction < 0 :
         print("Invalid initial day social distancing")
         sys.exit()
-    if social_distance_strictness < 0 or social_distance_strictness > 4:
+    if social_distance_strictness < 0 or social_distance_strictness > 100:
         print("Invalid social distancing value")
         sys.exit()
     if n_initial_infected_nodes < 0 or n_initial_infected_nodes > n_of_families:
@@ -179,12 +180,6 @@ def run_simulation(n_of_families = 250,
         sys.exit()
     if policy_test == "":
         n_test = 0
-    if restriction_duration == 0:
-        restriction_decreasing = False
-        social_distance_strictness = 0
-    if social_distance_strictness == 0:
-        restriction_decreasing = False
-        restriction_duration = 0
     if gamma < 0 :
         print("Value of gamma must greater than 0")
         sys.exit()
@@ -202,9 +197,8 @@ def run_simulation(n_of_families = 250,
         sys.exit()
 
     # making parameters consistent
-    if restriction_duration == 0 or social_distance_strictness == 0:
+    if social_distance_strictness == 0:
         restriction_decreasing = False
-        social_distance_strictness = 0
         initial_day_restriction = 0
         restriction_duration = 0
 
