@@ -487,8 +487,8 @@ def step(G, step_index, incubation_days, infection_duration, transmission_rate,
         How many days the social distancing last. Use -1 to make the restriction last till the end of the simulation
 
     social_distance_strictness: int
-        How strict from 0 to 4 the social distancing measures are. 
-        Represent the portion of contact that are dropped in the network (0, 25%, 50%, 75%, 100%)
+        How strict from 0 to 100 the social distancing measures are. 
+        Represent the percentage of contact that are dropped in the network
         Note that family contacts are not included in this reduction
 
     restriction_decreasing: bool
@@ -535,16 +535,16 @@ def step(G, step_index, incubation_days, infection_duration, transmission_rate,
     # generate new edges
     if not restriction_duration:
         if step_index >= initial_day_restriction:
-            step_edges(G, 1 - (25 * social_distance_strictness / 100))
+            step_edges(G, 1 - (social_distance_strictness / 100))
         else:
             step_edges(G, 1)
     else:
         if step_index >= initial_day_restriction and step_index < initial_day_restriction + restriction_duration:
             if restriction_decreasing:
                 social_distance_strictness = compute_sd_reduction(step_index, initial_day_restriction, restriction_duration, social_distance_strictness)
-                step_edges(G, 1 - (25 * social_distance_strictness / 100))
+                step_edges(G, 1 - (social_distance_strictness / 100))
             else:
-                step_edges(G, 1 - (25 * social_distance_strictness / 100))
+                step_edges(G, 1 - (social_distance_strictness / 100))
         else:
             step_edges(G, 1)
     
